import pandas as pd
import numpy as np
import matplotlib.pyplot as plt
import seaborn as sns
from sklearn.model_selection import train_test_split
from sklearn.ensemble import RandomForestClassifier
from sklearn import metrics
from imblearn import over_sampling
import matplotlib.pyplot as plt
from eli5.sklearn import PermutationImportance
from sklearn.metrics import make_scorer
from sklearn import metrics
import math
from sklearn.metrics import roc_auc_score, roc_curve
import scipy
from sklearn.ensemble import AdaBoostClassifier


def make_tt(df):
	names = df.drop(['has_panel'], axis = 1).columns.tolist()
	Xtrain, Xtest, ytrain, ytest = train_test_split(df.drop(['has_panel'], axis = 1), df['has_panel'], test_size = .3, random_state = 0)
	return Xtrain, Xtest, ytrain, ytest, names

def kappa_score(y_test, y_pred):
	return metrics.cohen_kappa_score(y_test, y_pred)

def pr_score(y_test, y_pred):
	p, r, t = metrics.precision_recall_curve(y_test, y_pred)
	return metrics.auc(r, p)

def print_metrics(y_test, y_preds):
	acc = metrics.accuracy_score(y_test, y_preds)
	print ('ACCURACY: ', acc)
	conf_mat = metrics.confusion_matrix(y_test, y_preds)
	print ('CONFUSION MATRIX')
	print (conf_mat)
	class_rpt = metrics.classification_report(y_test, y_preds)
	print ('CLASSIFICATION REPORT')
	print(class_rpt)
	print ('AREA UNDER ROC CURVE: %f' %roc_auc_score(y_test, y_preds))
	p, r, t = metrics.precision_recall_curve(y_test, y_preds)
	print ('AREA UNDER P-R CURVE: %f' %metrics.auc(r, p))
	print ('COHEN KAPPA SCORE: %f' %metrics.cohen_kappa_score(y_test, y_preds))


def permuted_importances(X_test, y_test, trained_algo, n_iter, names):
	hypothesized_mean = 0 
	perm = PermutationImportance(trained_algo,cv='prefit', n_iter = n_iter, scoring=make_scorer(pr_score, greater_is_better = True)).fit(X_test, y_test)
	fdf = pd.DataFrame(list(perm.feature_importances_), index = names, columns = {'feats'})
	fdf['sds'] = perm.feature_importances_std_  
	fdf['t_stat'] = (fdf.feats-hypothesized_mean)/(fdf.sds/np.sqrt(n_iter))  
	fdf['p_val'] = scipy.stats.t.sf(abs(fdf['t_stat']), n_iter-1)*2
	print (fdf.sort_values(by=['feats'], ascending = False))
	return fdf.sort_values(by=['feats'], ascending = False)


def run_ada_importances(X_train, X_test, y_train, y_test, n_iter, names):
	print ('Starting AdaBoost Classifier...')
	ada = AdaBoostClassifier()
	ada.fit(X_train , y_train)
	print ('AdaBoost Classifier Results')
	print_metrics(y_test, ada.predict(X_test))
	adadf = permuted_importances(X_test, y_test, ada, n_iter, names)
	return adadf

#read in datasets
df200_n = pd.read_csv('df200_shell.csv')
df300_n = pd.read_csv('df300_shell.csv')
df400_n = pd.read_csv('df400_shell.csv')
df500_n = pd.read_csv('df500_shell.csv')
df600_n = pd.read_csv('df600_shell.csv')
df700_n = pd.read_csv('df700_shell.csv')
df800_n = pd.read_csv('df800_shell.csv')
df900_n = pd.read_csv('df900_shell.csv')
dfkm_n = pd.read_csv('dfkm_shell.csv')
df1100_n = pd.read_csv('df1100_shell.csv')
df1200_n = pd.read_csv('df1200_shell.csv')


#house value
df200_low_hh = df200_n[df200_n.med_house_val <= 150000]	
df200_low_hh.drop(columns=['med_house_val'], inplace=True)
df200_med_hh = df200_n[(df200_n['med_house_val'] > 150000) & (df200_n['med_house_val'] < 250000)]
df200_med_hh.drop(columns=['med_house_val'], inplace=True)
df200_high_hh = df200_n[df200_n.med_house_val >= 250000]		
df200_high_hh.drop(columns=['med_house_val'], inplace=True)

df300_low_hh = df300_n[df300_n.med_house_val <= 150000]	
df300_low_hh.drop(columns=['med_house_val'], inplace=True)
df300_med_hh = df300_n[(df300_n['med_house_val'] > 150000) & (df300_n['med_house_val'] < 250000)]
df300_med_hh.drop(columns=['med_house_val'], inplace=True)
df300_high_hh = df300_n[df300_n.med_house_val >= 250000]		
df300_high_hh.drop(columns=['med_house_val'], inplace=True)

df400_low_hh = df400_n[df400_n.med_house_val <= 150000]	
df400_low_hh.drop(columns=['med_house_val'], inplace=True)
df400_med_hh = df400_n[(df400_n['med_house_val'] > 150000) & (df400_n['med_house_val'] < 250000)]
df400_med_hh.drop(columns=['med_house_val'], inplace=True)
df400_high_hh = df400_n[df400_n.med_house_val >= 250000]		
df400_high_hh.drop(columns=['med_house_val'], inplace=True)

df500_low_hh = df500_n[df500_n.med_house_val <= 150000]	
df500_low_hh.drop(columns=['med_house_val'], inplace=True)
df500_med_hh = df500_n[(df500_n['med_house_val'] > 150000) & (df500_n['med_house_val'] < 250000)]
df500_med_hh.drop(columns=['med_house_val'], inplace=True)
df500_high_hh = df500_n[df500_n.med_house_val >= 250000]		
df500_high_hh.drop(columns=['med_house_val'], inplace=True)

df600_low_hh = df600_n[df600_n.med_house_val <= 150000]	
df600_low_hh.drop(columns=['med_house_val'], inplace=True)
df600_med_hh = df600_n[(df600_n['med_house_val'] > 150000) & (df600_n['med_house_val'] < 250000)]
df600_med_hh.drop(columns=['med_house_val'], inplace=True)
df600_high_hh = df600_n[df600_n.med_house_val >= 250000]		
df600_high_hh.drop(columns=['med_house_val'], inplace=True)

df700_low_hh = df700_n[df700_n.med_house_val <= 150000]	
df700_low_hh.drop(columns=['med_house_val'], inplace=True)
df700_med_hh = df700_n[(df700_n['med_house_val'] > 150000) & (df700_n['med_house_val'] < 250000)]
df700_med_hh.drop(columns=['med_house_val'], inplace=True)
df700_high_hh = df700_n[df700_n.med_house_val >= 250000]		
df700_high_hh.drop(columns=['med_house_val'], inplace=True)

df800_low_hh = df800_n[df800_n.med_house_val <= 150000]	
df800_low_hh.drop(columns=['med_house_val'], inplace=True)
df800_med_hh = df800_n[(df800_n['med_house_val'] > 150000) & (df800_n['med_house_val'] < 250000)]
df800_med_hh.drop(columns=['med_house_val'], inplace=True)
df800_high_hh = df800_n[df800_n.med_house_val >= 250000]		
df800_high_hh.drop(columns=['med_house_val'], inplace=True)

df900_low_hh = df900_n[df900_n.med_house_val <= 150000]	
df900_low_hh.drop(columns=['med_house_val'], inplace=True)
df900_med_hh = df900_n[(df900_n['med_house_val'] > 150000) & (df900_n['med_house_val'] < 250000)]
df900_med_hh.drop(columns=['med_house_val'], inplace=True)
df900_high_hh = df900_n[df900_n.med_house_val >= 250000]		
df900_high_hh.drop(columns=['med_house_val'], inplace=True)

df1000_low_hh = dfkm_n[dfkm_n.med_house_val <= 150000]	
df1000_low_hh.drop(columns=['med_house_val'], inplace=True)
df1000_med_hh = dfkm_n[(dfkm_n['med_house_val'] > 150000) & (dfkm_n['med_house_val'] < 250000)]
df1000_med_hh.drop(columns=['med_house_val'], inplace=True)
df1000_high_hh = dfkm_n[dfkm_n.med_house_val >= 250000]		
df1000_high_hh.drop(columns=['med_house_val'], inplace=True)

df1100_low_hh = df1100_n[df1100_n.med_house_val <= 150000]	
df1100_low_hh.drop(columns=['med_house_val'], inplace=True)
df1100_med_hh = df1100_n[(df1100_n['med_house_val'] > 150000) & (df1100_n['med_house_val'] < 250000)]
df1100_med_hh.drop(columns=['med_house_val'], inplace=True)
df1100_high_hh = df1100_n[df1100_n.med_house_val >= 250000]		
df1100_high_hh.drop(columns=['med_house_val'], inplace=True)

df1200_low_hh = df1200_n[df1200_n.med_house_val <= 150000]	
df1200_low_hh.drop(columns=['med_house_val'], inplace=True)
df1200_med_hh = df1200_n[(df1200_n['med_house_val'] > 150000) & (df1200_n['med_house_val'] < 250000)]
df1200_med_hh.drop(columns=['med_house_val'], inplace=True)
df1200_high_hh = df1200_n[df1200_n.med_house_val >= 250000]		
df1200_high_hh.drop(columns=['med_house_val'], inplace=True)



#200m
niter = 50
Xtrain, Xtest, ytrain, ytest, names = make_tt(df200_low_hh)
smote = over_sampling.SMOTE(random_state = 0) 
smtXtrain, smtytrain = smote.fit_sample(Xtrain, ytrain.ravel()) 
df21_hh = run_ada_importances(smtXtrain, Xtest, smtytrain, ytest, niter, names)

Xtrain, Xtest, ytrain, ytest, names = make_tt(df200_med_hh)
smote = over_sampling.SMOTE(random_state = 0) 
smtXtrain, smtytrain = smote.fit_sample(Xtrain, ytrain.ravel()) 
df22_hh = run_ada_importances(smtXtrain, Xtest, smtytrain, ytest, niter, names)

Xtrain, Xtest, ytrain, ytest, names = make_tt(df200_high_hh)
smote = over_sampling.SMOTE(random_state = 0) 
smtXtrain, smtytrain = smote.fit_sample(Xtrain, ytrain.ravel()) 
df23_hh = run_ada_importances(smtXtrain, Xtest, smtytrain, ytest, niter, names)

#300m
Xtrain, Xtest, ytrain, ytest, names = make_tt(df300_low_hh)
smote = over_sampling.SMOTE(random_state = 0) 
smtXtrain, smtytrain = smote.fit_sample(Xtrain, ytrain.ravel()) 
df31_hh = run_ada_importances(smtXtrain, Xtest, smtytrain, ytest, niter, names)

Xtrain, Xtest, ytrain, ytest, names = make_tt(df300_med_hh)
smote = over_sampling.SMOTE(random_state = 0) 
smtXtrain, smtytrain = smote.fit_sample(Xtrain, ytrain.ravel()) 
df32_hh = run_ada_importances(smtXtrain, Xtest, smtytrain, ytest, niter, names)

Xtrain, Xtest, ytrain, ytest, names = make_tt(df300_high_hh)
smote = over_sampling.SMOTE(random_state = 0) 
smtXtrain, smtytrain = smote.fit_sample(Xtrain, ytrain.ravel()) 
df33_hh = run_ada_importances(smtXtrain, Xtest, smtytrain, ytest, niter, names)

#400m
Xtrain, Xtest, ytrain, ytest, names = make_tt(df400_low_hh)
smote = over_sampling.SMOTE(random_state = 0) 
smtXtrain, smtytrain = smote.fit_sample(Xtrain, ytrain.ravel()) 
df41_hh = run_ada_importances(smtXtrain, Xtest, smtytrain, ytest, niter, names)

Xtrain, Xtest, ytrain, ytest, names = make_tt(df400_med_hh)
smote = over_sampling.SMOTE(random_state = 0) 
smtXtrain, smtytrain = smote.fit_sample(Xtrain, ytrain.ravel()) 
df42_hh = run_ada_importances(smtXtrain, Xtest, smtytrain, ytest, niter, names)

Xtrain, Xtest, ytrain, ytest, names = make_tt(df400_high_hh)
smote = over_sampling.SMOTE(random_state = 0) 
smtXtrain, smtytrain = smote.fit_sample(Xtrain, ytrain.ravel()) 
df43_hh = run_ada_importances(smtXtrain, Xtest, smtytrain, ytest, niter, names)

#500m
Xtrain, Xtest, ytrain, ytest, names = make_tt(df500_low_hh)
smote = over_sampling.SMOTE(random_state = 0) 
smtXtrain, smtytrain = smote.fit_sample(Xtrain, ytrain.ravel()) 
df51_hh = run_ada_importances(smtXtrain, Xtest, smtytrain, ytest, niter, names)

Xtrain, Xtest, ytrain, ytest, names = make_tt(df500_med_hh)
smote = over_sampling.SMOTE(random_state = 0) 
smtXtrain, smtytrain = smote.fit_sample(Xtrain, ytrain.ravel()) 
df52_hh = run_ada_importances(smtXtrain, Xtest, smtytrain, ytest, niter, names)

Xtrain, Xtest, ytrain, ytest, names = make_tt(df500_high_hh)
smote = over_sampling.SMOTE(random_state = 0) 
smtXtrain, smtytrain = smote.fit_sample(Xtrain, ytrain.ravel()) 
df53_hh = run_ada_importances(smtXtrain, Xtest, smtytrain, ytest, niter, names)


#600m
Xtrain, Xtest, ytrain, ytest, names = make_tt(df600_low_hh)
smote = over_sampling.SMOTE(random_state = 0) 
smtXtrain, smtytrain = smote.fit_sample(Xtrain, ytrain.ravel()) 
df61_hh = run_ada_importances(smtXtrain, Xtest, smtytrain, ytest, niter, names)

Xtrain, Xtest, ytrain, ytest, names = make_tt(df600_med_hh)
smote = over_sampling.SMOTE(random_state = 0) 
smtXtrain, smtytrain = smote.fit_sample(Xtrain, ytrain.ravel()) 
df62_hh = run_ada_importances(smtXtrain, Xtest, smtytrain, ytest, niter, names)

Xtrain, Xtest, ytrain, ytest, names = make_tt(df600_high_hh)
smote = over_sampling.SMOTE(random_state = 0) 
smtXtrain, smtytrain = smote.fit_sample(Xtrain, ytrain.ravel()) 
df63_hh = run_ada_importances(smtXtrain, Xtest, smtytrain, ytest, niter, names)

#700m
Xtrain, Xtest, ytrain, ytest, names = make_tt(df700_low_hh)
smote = over_sampling.SMOTE(random_state = 0) 
smtXtrain, smtytrain = smote.fit_sample(Xtrain, ytrain.ravel()) 
df71_hh = run_ada_importances(smtXtrain, Xtest, smtytrain, ytest, niter, names)

Xtrain, Xtest, ytrain, ytest, names = make_tt(df700_med_hh)
smote = over_sampling.SMOTE(random_state = 0) 
smtXtrain, smtytrain = smote.fit_sample(Xtrain, ytrain.ravel()) 
df72_hh = run_ada_importances(smtXtrain, Xtest, smtytrain, ytest, niter, names)

Xtrain, Xtest, ytrain, ytest, names = make_tt(df700_high_hh)
smote = over_sampling.SMOTE(random_state = 0) 
smtXtrain, smtytrain = smote.fit_sample(Xtrain, ytrain.ravel()) 
df73_hh = run_ada_importances(smtXtrain, Xtest, smtytrain, ytest, niter, names)

#800m
Xtrain, Xtest, ytrain, ytest, names = make_tt(df800_low_hh)
smote = over_sampling.SMOTE(random_state = 0) 
smtXtrain, smtytrain = smote.fit_sample(Xtrain, ytrain.ravel()) 
df81_hh = run_ada_importances(smtXtrain, Xtest, smtytrain, ytest, niter, names)

Xtrain, Xtest, ytrain, ytest, names = make_tt(df800_med_hh)
smote = over_sampling.SMOTE(random_state = 0) 
smtXtrain, smtytrain = smote.fit_sample(Xtrain, ytrain.ravel()) 
df82_hh = run_ada_importances(smtXtrain, Xtest, smtytrain, ytest, niter, names)

Xtrain, Xtest, ytrain, ytest, names = make_tt(df800_high_hh)
smote = over_sampling.SMOTE(random_state = 0) 
smtXtrain, smtytrain = smote.fit_sample(Xtrain, ytrain.ravel()) 
df83_hh = run_ada_importances(smtXtrain, Xtest, smtytrain, ytest, niter, names)

#900m
Xtrain, Xtest, ytrain, ytest, names = make_tt(df900_low_hh)
smote = over_sampling.SMOTE(random_state = 0) 
smtXtrain, smtytrain = smote.fit_sample(Xtrain, ytrain.ravel()) 
df91_hh = run_ada_importances(smtXtrain, Xtest, smtytrain, ytest, niter, names)

Xtrain, Xtest, ytrain, ytest, names = make_tt(df900_med_hh)
smote = over_sampling.SMOTE(random_state = 0) 
smtXtrain, smtytrain = smote.fit_sample(Xtrain, ytrain.ravel()) 
df92_hh = run_ada_importances(smtXtrain, Xtest, smtytrain, ytest, niter, names)

Xtrain, Xtest, ytrain, ytest, names = make_tt(df900_high_hh)
smote = over_sampling.SMOTE(random_state = 0) 
smtXtrain, smtytrain = smote.fit_sample(Xtrain, ytrain.ravel()) 
df93_hh = run_ada_importances(smtXtrain, Xtest, smtytrain, ytest, niter, names)


#1km
Xtrain, Xtest, ytrain, ytest, names = make_tt(df1000_low_hh)
smote = over_sampling.SMOTE(random_state = 0) 
smtXtrain, smtytrain = smote.fit_sample(Xtrain, ytrain.ravel()) 
df11_hh = run_ada_importances(smtXtrain, Xtest, smtytrain, ytest, niter, names)

Xtrain, Xtest, ytrain, ytest, names = make_tt(df1000_med_hh)
smote = over_sampling.SMOTE(random_state = 0) 
smtXtrain, smtytrain = smote.fit_sample(Xtrain, ytrain.ravel()) 
df12_hh = run_ada_importances(smtXtrain, Xtest, smtytrain, ytest, niter, names)

Xtrain, Xtest, ytrain, ytest, names = make_tt(df1000_high_hh)
smote = over_sampling.SMOTE(random_state = 0) 
smtXtrain, smtytrain = smote.fit_sample(Xtrain, ytrain.ravel()) 
df13_hh = run_ada_importances(smtXtrain, Xtest, smtytrain, ytest, niter, names)


#1100m
Xtrain, Xtest, ytrain, ytest, names = make_tt(df1100_low_hh)
smote = over_sampling.SMOTE(random_state = 0) 
smtXtrain, smtytrain = smote.fit_sample(Xtrain, ytrain.ravel()) 
df111_hh = run_ada_importances(smtXtrain, Xtest, smtytrain, ytest, niter, names)

Xtrain, Xtest, ytrain, ytest, names = make_tt(df1100_med_hh)
smote = over_sampling.SMOTE(random_state = 0) 
smtXtrain, smtytrain = smote.fit_sample(Xtrain, ytrain.ravel()) 
df112_hh = run_ada_importances(smtXtrain, Xtest, smtytrain, ytest, niter, names)

Xtrain, Xtest, ytrain, ytest, names = make_tt(df1100_high_hh)
smote = over_sampling.SMOTE(random_state = 0) 
smtXtrain, smtytrain = smote.fit_sample(Xtrain, ytrain.ravel()) 
df113_hh = run_ada_importances(smtXtrain, Xtest, smtytrain, ytest, niter, names)

#1200m
Xtrain, Xtest, ytrain, ytest, names = make_tt(df1200_low_hh)
smote = over_sampling.SMOTE(random_state = 0) 
smtXtrain, smtytrain = smote.fit_sample(Xtrain, ytrain.ravel()) 
df121_hh = run_ada_importances(smtXtrain, Xtest, smtytrain, ytest, niter, names)

Xtrain, Xtest, ytrain, ytest, names = make_tt(df1200_med_hh)
smote = over_sampling.SMOTE(random_state = 0) 
smtXtrain, smtytrain = smote.fit_sample(Xtrain, ytrain.ravel()) 
df122_hh = run_ada_importances(smtXtrain, Xtest, smtytrain, ytest, niter, names)

Xtrain, Xtest, ytrain, ytest, names = make_tt(df1200_high_hh)
smote = over_sampling.SMOTE(random_state = 0) 
smtXtrain, smtytrain = smote.fit_sample(Xtrain, ytrain.ravel()) 
df123_hh = run_ada_importances(smtXtrain, Xtest, smtytrain, ytest, niter, names)


#HOUSE VALUE
#plot the values, 200m
val_list2 = []
val_list2.append(df21_hh['feats']['norm_shell200']*100)
val_list2.append(df22_hh['feats']['norm_shell200']*100)
val_list2.append(df23_hh['feats']['norm_shell200']*100)
dfplot = pd.DataFrame(val_list2, columns =['200m'], index = ['Low', 'Med', 'High'])

#plot the values, 300m
val_list3 = []
val_list3.append(df31_hh['feats']['norm_shell300']*100)
val_list3.append(df32_hh['feats']['norm_shell300']*100)
val_list3.append(df33_hh['feats']['norm_shell300']*100)
dfplot['300m'] = val_list3

#plot the values, 400m
val_list4 = []
val_list4.append(df41_hh['feats']['norm_shell400']*100)
val_list4.append(df42_hh['feats']['norm_shell400']*100)
val_list4.append(df43_hh['feats']['norm_shell400']*100)
dfplot['400m'] = val_list4

#plot the values, 500m
val_list5 = []
val_list5.append(df51_hh['feats']['norm_shell500']*100)
val_list5.append(df52_hh['feats']['norm_shell500']*100)
val_list5.append(df53_hh['feats']['norm_shell500']*100)
dfplot['500m'] = val_list5

#plot the values, 600m
val_list6 = []
val_list6.append(df61_hh['feats']['norm_shell600']*100)
val_list6.append(df62_hh['feats']['norm_shell600']*100)
val_list6.append(df63_hh['feats']['norm_shell600']*100)
dfplot['600m'] = val_list6

#plot the values, 700m
val_list7 = []
val_list7.append(df71_hh['feats']['norm_shell700']*100)
val_list7.append(df72_hh['feats']['norm_shell700']*100)
val_list7.append(df73_hh['feats']['norm_shell700']*100)
dfplot['700m'] = val_list7

#plot the values, 800m
val_list8 = []
val_list8.append(df81_hh['feats']['norm_shell800']*100)
val_list8.append(df82_hh['feats']['norm_shell800']*100)
val_list8.append(df83_hh['feats']['norm_shell800']*100)
dfplot['800m'] = val_list8

#plot the values, 900m
val_list9 = []
val_list9.append(df91_hh['feats']['norm_shell900']*100)
val_list9.append(df92_hh['feats']['norm_shell900']*100)
val_list9.append(df93_hh['feats']['norm_shell900']*100)
dfplot['900m'] = val_list9

#plot the values, 700m
val_listkm = []
val_listkm.append(df11_hh['feats']['norm_shellkm']*100)
val_listkm.append(df12_hh['feats']['norm_shellkm']*100)
val_listkm.append(df13_hh['feats']['norm_shellkm']*100)
dfplot['1km'] = val_listkm

#plot the values, 700m
val_list11 = []
val_list11.append(df111_hh['feats']['norm_shell1100']*100)
val_list11.append(df112_hh['feats']['norm_shell1100']*100)
val_list11.append(df113_hh['feats']['norm_shell1100']*100)
dfplot['1100m'] = val_list11

#plot the values, 700m
val_list12 = []
val_list12.append(df121_hh['feats']['norm_shell1200']*100)
val_list12.append(df122_hh['feats']['norm_shell1200']*100)
val_list12.append(df123_hh['feats']['norm_shell1200']*100)
dfplot['1200m'] = val_list12



fig, (ax2, ax3, ax4, ax5, ax6, ax7, ax8, ax9, ax10, ax11, ax12) = plt.subplots(1, 11, sharey=True)
ax2.set_ylabel('Importance Score (x100)')
ax2.yaxis.label.set_size(14)
ax2.bar(dfplot.index, dfplot['200m'], color = ['#39ac39', '#66cc66', '#b3e6b3'] )
plt.setp(ax2.get_xticklabels(), ha="right",rotation=45,rotation_mode="anchor")
#ax1.set_ylim([60,130])
ax2.set_title('200m')
ax2.title.set_size(12)
ax3.bar(dfplot.index, dfplot['300m'], color = ['#39ac39', '#66cc66', '#b3e6b3'])
plt.setp(ax3.get_xticklabels(), ha="right",rotation=45,rotation_mode="anchor")
#ax1.set_ylim([60,130])
ax3.set_title('300m')
ax3.title.set_size(12)
ax4.bar(dfplot.index, dfplot['400m'], color = ['#39ac39', '#66cc66', '#b3e6b3'])
plt.setp(ax4.get_xticklabels(), ha="right",rotation=45,rotation_mode="anchor")
#ax1.set_ylim([60,130])
ax4.set_title('400m')
ax4.title.set_size(12)
ax5.bar(dfplot.index, dfplot['500m'], color = ['#39ac39', '#66cc66', '#b3e6b3'])
plt.setp(ax5.get_xticklabels(), ha="right",rotation=45,rotation_mode="anchor")
#ax2.set_ylim([60,130])
ax5.set_title('500m')
ax5.title.set_size(12)
ax6.bar(dfplot.index, dfplot['600m'], color = ['#39ac39', '#66cc66', '#b3e6b3'])
plt.setp(ax6.get_xticklabels(), ha="right",rotation=45,rotation_mode="anchor")
#ax2.set_ylim([60,130])
ax6.set_title('600m')
ax6.title.set_size(12)
ax7.bar(dfplot.index, dfplot['700m'], color = ['#39ac39', '#66cc66', '#b3e6b3'])
plt.setp(ax7.get_xticklabels(), ha="right",rotation=45,rotation_mode="anchor")
#ax2.set_ylim([60,130])
ax7.set_title('700m')
ax7.title.set_size(12)
ax8.bar(dfplot.index, dfplot['800m'], color = ['#39ac39', '#66cc66', '#b3e6b3'])
plt.setp(ax8.get_xticklabels(), ha="right",rotation=45,rotation_mode="anchor")
#ax2.set_ylim([60,130])
ax8.set_title('800m')
ax8.title.set_size(12)
ax9.bar(dfplot.index, dfplot['900m'], color = ['#39ac39', '#66cc66', '#b3e6b3'])
plt.setp(ax9.get_xticklabels(), ha="right",rotation=45,rotation_mode="anchor")
#ax2.set_ylim([60,130])
ax9.set_title('900m')
ax9.title.set_size(12)
ax10.bar(dfplot.index, dfplot['1km'], color = ['#39ac39', '#66cc66', '#b3e6b3'])
plt.setp(ax10.get_xticklabels(), ha="right",rotation=45,rotation_mode="anchor")
#ax2.set_ylim([60,130])
ax10.set_title('1000m')
ax10.title.set_size(12)
ax11.bar(dfplot.index, dfplot['1100m'], color = ['#39ac39', '#66cc66', '#b3e6b3'])
plt.setp(ax11.get_xticklabels(), ha="right",rotation=45,rotation_mode="anchor")
#ax2.set_ylim([60,130])
ax11.set_title('1100m')
ax11.title.set_size(12)
ax12.bar(dfplot.index, dfplot['1200m'], color = ['#39ac39', '#66cc66', '#b3e6b3'])
plt.setp(ax12.get_xticklabels(), ha="right",rotation=45,rotation_mode="anchor")
#ax2.set_ylim([60,130])
ax12.set_title('1200m')
ax12.title.set_size(12)
plt.show()
